summaryrefslogtreecommitdiff
path: root/src/modinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/modinfo.h')
-rw-r--r--src/modinfo.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/modinfo.h b/src/modinfo.h
index 0fbcd1c0..ff6c4001 100644
--- a/src/modinfo.h
+++ b/src/modinfo.h
@@ -606,10 +606,10 @@ public: // Methods after this do not come from IModInterface:
//
bool isFixedPriority() const { return isBackup() || isOverwrite(); }
/**
* @return true if the mod is always enabled.
*/
virtual bool alwaysEnabled() const { return false; }
+ virtual bool alwaysDisabled() const { return false; }
/**
* @return true if the mod can be updated.
@@ -606,10 +606,10 @@ public: // Methods after this do not come from IModInterface:
//
bool isFixedPriority() const { return isBackup() || isOverwrite(); }
- /**
- * @return true if the mod is always enabled.
- */
+ // check if this mod should always be enabled or disabled
+ //
virtual bool alwaysEnabled() const { return false; }